@@ -16,16 +16,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import multiprocessing
 import os
 import pytest
-import queue
 
-from pynicotine.shares import Shares
+from collections import deque
+
 from pynicotine.config import Config
-from pynicotine.utils import apply_translation
+from pynicotine.i18n import apply_translation
+from pynicotine.shares import Shares
 
-DB_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "dbs")
 SHARES_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "sharedfiles")
 
 
@@ -34,17 +33,24 @@ def setup():
     # Setting gettext and locale
     apply_translation()
 
-    # Use 'spawn' start method for file scanning process
-    multiprocessing.set_start_method("spawn")
+
+@pytest.fixture
+def config():
+    config = Config()
+    config.data_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "dbs")
+    config.filename = os.path.join(config.data_dir, "temp_config")
+
+    config.load_config()
+    return config
 
 
-def test_shares_scan():
+def test_shares_scan(config):
     """ Test a full shares scan """
 
-    config = Config("temp_config", DB_DIR)
     config.sections["transfers"]["shared"] = [("Shares", SHARES_DIR)]
+    config.sections["transfers"]["rescanonstartup"] = False
 
-    shares = Shares(None, config, queue.Queue(0))
+    shares = Shares(None, config, deque())
     shares.rescan_public_shares(thread=False)
 
     # Verify that modification time was saved for shares folder
@@ -75,13 +81,13 @@ def test_shares_scan():
     shares.close_shares("normal")
 
 
-def test_hidden_file_folder_scan():
+def test_hidden_file_folder_scan(config):
     """ Test that hidden files and folders are excluded """
 
-    config = Config("temp_config", DB_DIR)
     config.sections["transfers"]["shared"] = [("Shares", SHARES_DIR)]
+    config.sections["transfers"]["rescanonstartup"] = False
 
-    shares = Shares(None, config, queue.Queue(0))
+    shares = Shares(None, config, deque())
     shares.rescan_public_shares(thread=False)
 
     # Check folders
@@ -107,14 +113,14 @@ def test_hidden_file_folder_scan():
     shares.close_shares("normal")
 
 
-def test_shares_add_downloaded():
+def test_shares_add_downloaded(config):
     """ Test that downloaded files are added to shared files """
 
-    config = Config("temp_config", DB_DIR)
     config.sections["transfers"]["shared"] = [("Downloaded", SHARES_DIR)]
+    config.sections["transfers"]["rescanonstartup"] = False
     config.sections["transfers"]["sharedownloaddir"] = True
 
-    shares = Shares(None, config, queue.Queue(0), None)
+    shares = Shares(None, config, deque(), None)
     shares.add_file_to_shared(os.path.join(SHARES_DIR, 'nicotinetestdata.mp3'))
 
     assert ('nicotinetestdata.mp3', 80919, (128, 0), 5) in shares.share_dbs["files"]["Downloaded"]
