@@ -19,15 +19,15 @@
 
 import socket
 
-from queue import Queue
+from collections import deque
 from time import sleep
-from unittest.mock import Mock, MagicMock
+from unittest.mock import Mock
 
 import pytest
 
+from pynicotine.i18n import apply_translation
 from pynicotine.slskproto import SlskProtoThread
 from pynicotine.slskmessages import ServerConn, Login, SetWaitPort
-from pynicotine.utils import apply_translation
 from test.unit.mock_socket import monkeypatch_socket, monkeypatch_select
 
 # Time (in s) needed for SlskProtoThread main loop to run at least once
@@ -41,31 +41,26 @@ def translation():
     apply_translation()
 
 
-@pytest.fixture
-def config():
-    config = MagicMock()
-    config.sections = {'server': {'portrange': (1, 2)}, 'transfers': {'downloadlimit': 10}}
-    return config
-
-
-def test_instantiate_proto(config) -> None:
+def test_instantiate_proto() -> None:
     proto = SlskProtoThread(
-        ui_callback=Mock(), queue=Mock(), bindip='',
-        port=None, config=config, eventprocessor=Mock()
+        ui_callback=Mock(), queue=deque(), bindip='',
+        port=None, port_range=(1, 2), network_filter=None,
+        eventprocessor=Mock()
     )
     proto.server_connect()
     proto.abort()
 
 
-def test_server_conn(config, monkeypatch) -> None:
+def test_server_conn(monkeypatch) -> None:
     mock_socket = monkeypatch_socket(monkeypatch, LOGIN_DATAFILE)
     monkeypatch_select(monkeypatch)
     proto = SlskProtoThread(
-        ui_callback=Mock(), queue=Queue(0), bindip='',
-        port=None, config=config, eventprocessor=Mock()
+        ui_callback=Mock(), queue=deque(), bindip='',
+        port=None, port_range=(1, 2), network_filter=None,
+        eventprocessor=Mock()
     )
     proto.server_connect()
-    proto._queue.put(ServerConn())
+    proto._queue.append(ServerConn())
 
     sleep(SLSKPROTO_RUN_TIME)
 
@@ -91,19 +86,20 @@ def test_server_conn(config, monkeypatch) -> None:
     assert mock_socket.close.call_count == 1
 
 
-def test_login(config, monkeypatch) -> None:
+def test_login(monkeypatch) -> None:
     monkeypatch_select(monkeypatch)
     proto = SlskProtoThread(
-        ui_callback=Mock(), queue=Queue(0), bindip='',
-        port=None, config=config, eventprocessor=Mock()
+        ui_callback=Mock(), queue=deque(), bindip='',
+        port=None, port_range=(1, 2), network_filter=None,
+        eventprocessor=Mock()
     )
     proto.server_connect()
-    proto._queue.put(ServerConn())
+    proto._queue.append(ServerConn())
 
     sleep(SLSKPROTO_RUN_TIME / 2)
 
-    proto._queue.put(Login('username', 'password', 157))
-    proto._queue.put(SetWaitPort(1))
+    proto._queue.append(Login('username', 'password', 157))
+    proto._queue.append(SetWaitPort(1))
 
     sleep(SLSKPROTO_RUN_TIME)
 
